Package: mbQTL
Type: Package
Title: mbQTL: A package for SNP-Taxa mGWAS analysis
Version: 1.13.0
Authors@R: 
    c(person(given = "Mercedeh",
           family = "Movassagh",
           role = c("aut", "cre"),
           email = "mercedeh.movassagh@yale.edu",
           comment = c(ORCID = "0000-0001-7690-0230")),
           person("Steven","Schiff", role="aut"),
           person("Joseph N", "Paulson", role="aut"))
Description: mbQTL is a statistical R package for simultaneous 16srRNA,16srDNA (microbial)
 and variant, SNP, SNV (host) relationship, correlation, regression studies.
 We apply linear, logistic and correlation based statistics to identify the relationships
 of taxa, genus, species and variant, SNP, SNV in the infected host. We produce various 
 statistical significance measures such as P values, FDR, BC and probability estimation to
 show significance of these relationships. Further we provide various visualization function
 for ease and clarification of the results of these analysis. The package is compatible with
 dataframe, MRexperiment and text formats.
License: MIT + file LICENSE
Encoding: UTF-8
Depends: R (>= 4.3.0)
DeploySubPath: mbQTL
biocViews: SNP, Microbiome, WholeGenome, Metagenomics,
        StatisticalMethod, Regression
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.1
Imports: MatrixEQTL, dplyr, ggplot2, readxl, stringr, tidyr,
        metagenomeSeq, pheatmap, broom, graphics, stats, methods
Suggests: knitr, rmarkdown, BiocStyle
VignetteBuilder: knitr
URL: "https://github.com/Mercedeh66/mbQTL"
BugReport: "https://github.com/Mercedeh66/mbQTL/issues"
git_url: https://git.bioconductor.org/packages/mbQTL
git_branch: devel
git_last_commit: dcb1e5a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 22:35:45 UTC; biocbuild
Author: Mercedeh Movassagh [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7690-0230>),
  Steven Schiff [aut],
  Joseph N Paulson [aut]
Maintainer: Mercedeh Movassagh <mercedeh.movassagh@yale.edu>
Built: R 4.6.0; ; 2026-05-19 04:57:32 UTC; unix
