# Generated by roxygen2: do not edit by hand

export(allToAllProduct)
export(coringTaxa)
export(histPvalueLm)
export(linearTaxaSnp)
export(logRegSnpsTaxa)
export(logitPlotSnpTaxa)
export(mbQtlCorHeatmap)
export(metagenomeSeqToMbqtl)
export(qqPlotLm)
export(taxaSnpCor)
import(MatrixEQTL)
import(broom)
import(dplyr)
import(ggplot2)
import(metagenomeSeq)
import(pheatmap)
import(readxl)
import(stringr)
import(tidyr)
importFrom(graphics,hist)
importFrom(methods,is)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,glm)
importFrom(stats,p.adjust)
importFrom(stats,quantile)
