#<img src="man/figures/logo.png" align="right" alt="logo.png" width="180" />

# mbQTL

<!-- badges: start -->
[![BioC status](http://www.bioconductor.org/shields/build/release/bioc/mbQTL.svg)](https://bioconductor.org/checkResults/release/bioc-LATEST/mbQTL)
<!-- badges: end -->

## Installation
```
devtools::install_github('Mercedeh66/mbQTL')

if (!require("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("mbQTL")
```
## Issues and bug reports
Please use https://github.com/Mercedeh66/mbQTL/issues to submit issues, bug reports, and comments.

